==> dojo-1.9.4.tgz: package/cldr/nls/he/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"eraNarrow": [
		"שנת היג׳רה"
	],
	"days-format-short": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו'",
		"ש'"
	],
	"dateFormat-long": "d בMMMM y G",
	"months-format-wide": [
		"מוחרם",
		"צפר",
		"רביע אל-אוול",
		"רביע א-ת׳אני",
		"ג׳ומאדא אל-אולא",
		"ג׳ומאדא א-ת׳אניה",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל-קעדה",
		"ד׳ו אל-חיג׳ה"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.M.y",
	"dateFormatItem-Md": "d/M",
	"field-era": "תקופה",
	"months-standAlone-wide": [
		"מוחרם",
		"צפר",
		"רביע אל-אוול",
		"רביע א-ת׳אני",
		"ג׳ומאדא אל-אולא",
		"ג׳ומאדא א-ת׳אניה",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל-קעדה",
		"ד׳ו אל-חיג׳ה"
	],
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-year": "שנה",
	"field-hour": "שעה",
	"months-format-abbr": [
		"מוחרם",
		"צפר",
		"רביע א׳",
		"רביע ב׳",
		"ג׳ומאדא א׳",
		"ג׳ומאדא ב׳",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל-קעדה",
		"ד׳ו אל-חיג׳ה"
	],
	"field-day-relative+0": "היום",
	"field-day-relative+1": "מחר",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"months-standAlone-abbr": [
		"מוחרם",
		"צפר",
		"רביע א׳",
		"רביע ב׳",
		"ג׳ומאדא א׳",
		"ג׳ומאדא ב׳",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל-קעדה",
		"ד׳ו אל-חיג׳ה"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMM y",
	"dateFormatItem-yyyyMMM": "MMM y",
	"dateFormatItem-yyyyMMMd": "d בMMM y",
	"dateFormatItem-Hm": "HH:mm",
	"eraAbbr": [
		"שנת היג׳רה"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפה״צ/אחה״צ",
	"dateFormatItem-d": "d",
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "h a",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "שנה שעברה",
	"field-month-relative+-1": "חודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"eraNames": [
		"שנת היג׳רה"
	],
	"days-format-narrow": [
		"א'",
		"ב'",
		"ג'",
		"ד'",
		"ה'",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "חודש",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו",
		"ש"
	],
	"dayPeriods-format-wide-am": "לפנה״צ",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "שנייה",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "חודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y G",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "שבוע שעבר",
	"dateFormatItem-yyyyM": "M/y",
	"field-year-relative+1": "שנה הבאה",
	"dateFormatItem-yyyyQQQQ": "QQQQ y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "שבוע הבא"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/he/islamic.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-second-relative+0": "עכשיו",
	"quarters-standAlone-narrow": [
		"ר1",
		"ר2",
		"ר3",
		"ר4"
	],
	"field-weekday": "יום בשבוע",
	"field-wed-relative+0": "יום רביעי",
	"field-wed-relative+1": "יום רביעי הבא",
	"dateFormatItem-GyMMMEd": "E, d בMMM y G",
	"dateFormatItem-MMMEd": "E, d בMMM",
	"eraNarrow": [
		"שנת היג׳רה"
	],
	"field-tue-relative+-1": "יום שלישי שעבר",
	"days-format-short": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormat-long": "d בMMMM y G",
	"field-fri-relative+-1": "יום שישי שעבר",
	"field-wed-relative+-1": "יום רביעי שעבר",
	"months-format-wide": [
		"מוחרם",
		"צפר",
		"רביע אל-אוול",
		"רביע א-ת׳אני",
		"ג׳ומאדא אל-אולא",
		"ג׳ומאדא א-ת׳אניה",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל־קעדה",
		"ד׳ו אל־חיג׳ה"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "אחה״צ",
	"dateFormat-full": "EEEE, d בMMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.M.y",
	"field-thu-relative+-1": "יום חמישי שעבר",
	"dateFormatItem-Md": "d/M",
	"field-era": "תקופה",
	"months-standAlone-wide": [
		"מוחרם",
		"צפר",
		"רביע אל־אוול",
		"רביע א־ת׳אני",
		"ג׳ומאדא אל־אולא",
		"ג׳ומאדא א־ת׳אניה",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל־קעדה",
		"ד׳ו אל־חיג׳ה"
	],
	"quarters-format-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"field-year": "שנה",
	"field-hour": "שעה",
	"months-format-abbr": [
		"מוחרם",
		"צפר",
		"רביע א׳",
		"רביע ב׳",
		"ג׳ומאדא א׳",
		"ג׳ומאדא ב׳",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל־קעדה",
		"ד׳ו אל־חיג׳ה"
	],
	"field-sat-relative+0": "יום שבת",
	"field-sat-relative+1": "יום שבת הבא",
	"field-day-relative+0": "היום",
	"field-thu-relative+0": "יום חמישי",
	"field-day-relative+1": "מחר",
	"field-thu-relative+1": "יום חמישי הבא",
	"dateFormatItem-GyMMMd": "d בMMM y G",
	"field-day-relative+2": "מחרתיים",
	"months-standAlone-abbr": [
		"מוחרם",
		"צפר",
		"רביע א׳",
		"רביע ב׳",
		"ג׳ומאדא א׳",
		"ג׳ומאדא ב׳",
		"רג׳ב",
		"שעבאן",
		"רמדאן",
		"שוואל",
		"ד׳ו אל-קעדה",
		"ד׳ו אל-חיג׳ה"
	],
	"quarters-format-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"quarters-standAlone-wide": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d בMMM y",
	"days-standAlone-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"dateFormatItem-yyyyMMM": "MMM y",
	"dateFormatItem-yyyyMMMd": "d בMMM y",
	"field-sun-relative+0": "יום ראשון",
	"dateFormatItem-Hm": "H:mm",
	"field-sun-relative+1": "יום ראשון הבא",
	"quarters-standAlone-abbr": [
		"רבעון 1",
		"רבעון 2",
		"רבעון 3",
		"רבעון 4"
	],
	"eraAbbr": [
		"שנת היג׳רה"
	],
	"field-minute": "דקה",
	"field-dayperiod": "לפנה״צ/אחה״צ",
	"dateFormatItem-d": "d",
	"field-day-relative+-1": "אתמול",
	"dateFormatItem-h": "h a",
	"field-day-relative+-2": "שלשום",
	"dateFormatItem-MMMd": "d בMMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "יום שישי",
	"field-fri-relative+1": "יום שישי הבא",
	"field-day": "יום",
	"days-format-wide": [
		"יום ראשון",
		"יום שני",
		"יום שלישי",
		"יום רביעי",
		"יום חמישי",
		"יום שישי",
		"יום שבת"
	],
	"field-zone": "אזור",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year-relative+-1": "השנה שעברה",
	"field-month-relative+-1": "החודש שעבר",
	"dateFormatItem-hm": "h:mm a",
	"days-format-abbr": [
		"יום א׳",
		"יום ב׳",
		"יום ג׳",
		"יום ד׳",
		"יום ה׳",
		"יום ו׳",
		"שבת"
	],
	"eraNames": [
		"שנת היג׳רה"
	],
	"days-format-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "חודש",
	"days-standAlone-narrow": [
		"א׳",
		"ב׳",
		"ג׳",
		"ד׳",
		"ה׳",
		"ו׳",
		"ש׳"
	],
	"field-tue-relative+0": "יום שלישי",
	"field-tue-relative+1": "יום שלישי הבא",
	"dayPeriods-format-wide-am": "לפנה״צ",
	"field-mon-relative+0": "יום שני",
	"field-mon-relative+1": "יום שני הבא",
	"dateFormat-short": "dd/MM/yy GGGGG",
	"field-second": "שנייה",
	"field-sat-relative+-1": "יום שבת שעבר",
	"field-sun-relative+-1": "יום ראשון שעבר",
	"field-month-relative+0": "החודש",
	"field-month-relative+1": "החודש הבא",
	"dateFormatItem-Ed": "E ה-d",
	"field-week": "שבוע",
	"dateFormat-medium": "d בMMM y G",
	"field-year-relative+0": "השנה",
	"field-week-relative+-1": "השבוע שעבר",
	"dateFormatItem-yyyyM": "M/y",
	"field-year-relative+1": "השנה הבאה",
	"dateFormatItem-yyyyQQQQ": "QQQQ y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "H:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "יום שני שעבר",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "השבוע",
	"field-week-relative+1": "השבוע הבא"
}
//end v1.x content
);
